//
//  YWSDKApi.h
//  YWSDK
//
//  Created by _zone on 2023/6/25.
//

#import <UIKit/UIKit.h>
#import <YWSDK/YWSDKRoleInfo.h>
#import <YWSDK/YWSDKOrderInfo.h>

NS_ASSUME_NONNULL_BEGIN

extern NSString* kYWSDKInitNotification;        // 初始化回调通知
extern NSString* kYWSDKLoginNotification;       // 登录回调通知
extern NSString* kYWSDKLogoutNotification;      // 注销回调通知
extern NSString* kYWSDKTradeNotification;       // 支付回调通知
extern NSString* kYWSDKSendRoleNotification;    // 上传角色回调通知

@interface YWSDKApi : NSObject

/**
 * 单例
 */
+ (YWSDKApi *)sharedInstance;

/**
 * 初始化 SDK
 *
 * @param appId     唯一标示符
 * @param appKey    唯一标示符
 */
- (void)initSDKWithAppId:(NSString *)appId appKey:(NSString *)appKey;

/**
 * 登录
 */
- (void)login;

/**
 * 支付
 *
 * @param orderInfo 订单信息
 */
- (void)trade:(YWSDKOrderInfo *)orderInfo;
           
/**
 * 角色上报
 */
- (void)sendGameRoleInfo:(YWSDKRoleInfo *)roleInfo;

/**
 * 注销登录
 */
- (void)logout;

/**
 * 切换账号
 */
- (void)switchAccount;

/**
 * 是否登录
 */
- (BOOL)isLogined;

/**
 * 显示悬浮窗界面
 */
- (void)showFloatView;

/**
 * 隐藏悬浮窗界面
 */
- (void)hideFloatView;

/**
 * 获取SDK版本信息
 */
- (NSString*)getSdkVersion;

/**
 * 获取channelCode
 */
- (NSString*)getChannelCode;

/**
 * 获取sdkPlatform
 */
- (NSString*)getSdkPlatform;

/**
 * 获取实名认证信息
 */
//- (NSDictionary *)getCheckIdentify;

#pragma mark - 周期函数

- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions;

- (BOOL)application:(UIApplication *)application openURL:(NSURL *)url options:(NSDictionary<NSString*, id> *)options;

- (void)applicationWillResignActive:(UIApplication *)application;

- (void)applicationDidEnterBackground:(UIApplication *)application;

- (void)applicationWillEnterForeground:(UIApplication *)application;

- (void)applicationDidBecomeActive:(UIApplication *)application;

- (void)applicationWillTerminate:(UIApplication *)application;

- (UIInterfaceOrientationMask)application:(UIApplication *)application supportedInterfaceOrientationsForWindow:(nullable UIWindow *)window;

@end

NS_ASSUME_NONNULL_END
